@@ -3,14 +3,10 @@ use crate::packet::Packet;
 
 #[derive(Debug, PartialEq)]
 pub enum ConvertPacketError {
-    /// Provided packet was not appropriately sized
     WrongSize,
-    /// The provided packet was of a wrong type
+    UnknownEnumVariant,
     WrongType,
-    /// Event specific error
     Event(EventError),
-    /// Postcard error
-    PostcardError(postcard::Error),
 }
 
 pub trait ConvertPacket<T> {
