@@ -6,7 +6,7 @@ use crate::event::event_code::*;
 use crate::event::EventError;
 use crate::packet::Packet;
 
-#[derive(Debug, Eq, PartialEq)]
+#[derive(Debug, Eq, PartialEq, Ord, PartialOrd)]
 pub struct ButtonPressedEvent {
     pub receiver_address: u16,
     pub button_address: u16,
@@ -59,7 +59,7 @@ impl ConvertPacket<ButtonPressedEvent> for ButtonPressedEvent {
     }
 }
 
-#[derive(Debug, Eq, PartialEq)]
+#[derive(Debug, Eq, PartialEq, Ord, PartialOrd)]
 pub struct ButtonReleasedEvent {
     pub receiver_address: u16,
     pub button_address: u16,
