@@ -23,3 +23,7 @@ pub const MESSAGE_EVENT_CODE: u16 = 0x000c;
 pub const BCM_ANIMATE_BRIGHTNESS_EVENT_CODE: u16 = 0x000d;
 
 pub const RELAY_SET_VALUE_EVENT_CODE: u16 = 0x000e;
+
+pub const GATEWAY_DISCOVER_EVENT_CODE: u16 = 0x000f;
+
+pub const PERIPHERAL_DATA_EVENT_CODE: u16 = 0x0010;
